@@ -94,7 +94,7 @@ class Uploader:
 
 
 def parse_arguments():
-    parser = argparse.ArgumentParser(formatter_class=argparse.RawTextHelpFormatter, prog='uploader',
+    parser = argparse.ArgumentParser(formatter_class=argparse.RawTextHelpFormatter, prog='xray-uploader',
                                      epilog="General purpose xray uploader.\n"
                                             "Currently either specify a testNG or a junit style xml file .\n")
 
